@@ -5,14 +5,15 @@
 #' @import RCurl
 #' @importFrom jsonlite toJSON fromJSON
 #' @export
-#' @examples{
+#' @examples \dontrun{
 #' GNRS_version_metadata <- GNRS_version()
 #' }
 #' 
 GNRS_version <- function(){
   
   # api url
-  url = "http://vegbiendev.nceas.ucsb.edu:8875/gnrs_api.php" # production: /var/www/gnrs
+  url = "http://vegbiendev.nceas.ucsb.edu:8875/gnrs_api.php" # production
+  #url = "http://vegbiendev.nceas.ucsb.edu:9875/gnrs_api.php" # development
   
   # set option mode.
   mode <- "meta"		
